@@ -1,14 +1,16 @@
 readme_template = """
 [![Build Status](https://travis-ci.com/{1}/{0}.svg?branch=master)](https://travis-ci.com/{1}/{0})
-[![Build status](https://ci.appveyor.com/api/projects/status/yvvmq5hyf7hj743a?svg=true)](https://ci.appveyor.com/project/{1}/{0})
 [![Build status](https://ci.appveyor.com/api/projects/status/yvvmq5hyf7hj743a/branch/master?svg=true)](https://ci.appveyor.com/project/{1}/{0}/branch/master)
 [![Documentation Status](https://readthedocs.org/projects/{0}/badge/?version=latest)](https://{0}.readthedocs.io/en/latest/?badge=latest)
-[![License: GPLV2](https://img.shields.io/badge/License-GPLV2-green.svg)](https://opensource.org/licenses/GPLV2)
+[![License: GPLv3](https://img.shields.io/badge/License-GPLV2-green.svg)](https://opensource.org/licenses/GPLV2)
 [![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
 [![Views](http://hits.dwyl.io/{1}/{0}.svg)](http://dwyl.io/{1}/{0})
 [![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg?style=flat-square)](https://github.com/{1}/{0}/pull/)
 [![GitHub pull-requests](https://img.shields.io/badge/Issues-pr-red.svg?style=flat-square)](https://github.com/{1}/{0}/pull/)
 [![Language](https://img.shields.io/badge/Language-{2}-{3}.svg)](https://github.com/TralahM)
+<img title="Watching" src="https://img.shields.io/github/watchers/{1}/{0}?label=Watchers&color=blue&style=flat-square">
+<img title="Stars" src="https://img.shields.io/github/stars/{1}/{0}?color=red&style=flat-square">
+<img title="Forks" src="https://img.shields.io/github/forks/{1}/{0}?color=green&style=flat-square">
 
 # {0}.
 
@@ -49,15 +51,15 @@ $ cd {0}
 
 # Self-Promotion
 
-[![TralahM](https://img.shields.io/badge/Twitter-TralahM-blue.svg?style=for-the-badge)](https://twitter.com/TralahM)
-[![TralahM](https://img.shields.io/badge/Github-TralahM-black.svg?style=for-the-badge)](https://github.com/TralahM)
+[![](https://img.shields.io/badge/Github-{1}-green?style=for-the-badge&logo=github)](https://github.com/{1})
+[![](https://img.shields.io/badge/Twitter-%40tralahtek-red?style=for-the-badge&logo=twitter)](https://twitter.com/{1})
 [![TralahM](https://img.shields.io/badge/Kaggle-TralahM-purple.svg?style=for-the-badge)](https://kaggle.com/TralahM)
-[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-red.svg?style=for-the-badge)](https://linkedin.com/in/TralahM)
+[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-red.svg?style=for-the-badge&logo=linkedin)](https://linkedin.com/in/TralahM)
 
 
 [![Blog](https://img.shields.io/badge/Blog-tralahm.tralahtek.com-blue.svg?style=for-the-badge)](https://tralahm.tralahtek.com)
 
-[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://tralahtek.com)
+[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://org.tralahtek.com)
 
 
 """
